@@ -1,13 +1,13 @@
 context("Custom S3")
 
-build_request <- function(bucket) {
+build_request <- function(bucket, operation) {
   metadata <- list(
     endpoints = list("*" = list(endpoint = "s3.amazonaws.com", global = FALSE)),
     service_name = "s3"
   )
   svc <- new_service(metadata, new_handlers("restxml", "s3"))
   op <- new_operation(
-    name = "ListObjects",
+    name = operation,
     http_method = "GET",
     http_path = "/{Bucket}",
     paginator = list()
@@ -19,15 +19,19 @@ build_request <- function(bucket) {
 }
 
 test_that("update_endpoint_for_s3_config", {
-  req <- build_request("foo")
+  req <- build_request(bucket = "foo", operation = "ListObjects")
   result <- update_endpoint_for_s3_config(req)
   expect_equal(result$http_request$url$host, "foo.s3.amazonaws.com")
 
-  req <- build_request("foo-bar")
+  req <- build_request(bucket = "foo-bar", operation = "ListObjects")
   result <- update_endpoint_for_s3_config(req)
   expect_equal(result$http_request$url$host, "foo-bar.s3.amazonaws.com")
 
-  req <- build_request("foo.bar")
+  req <- build_request(bucket = "foo.bar", operation = "ListObjects")
+  result <- update_endpoint_for_s3_config(req)
+  expect_equal(result$http_request$url$host, "s3.amazonaws.com")
+
+  req <- build_request(bucket = "foo-bar", operation = "GetBucketLocation")
   result <- update_endpoint_for_s3_config(req)
   expect_equal(result$http_request$url$host, "s3.amazonaws.com")
 })
