@@ -152,7 +152,7 @@ test_that("build blob argument", {
 op_input8 <- function(TimeArg) {
   args <- list(TimeArg = TimeArg)
   interface <- Structure(
-    TimeArg = Scalar(type = "timestamp", .tags = list(timestampFormat = "iso8601"))
+    TimeArg = Scalar(type = "timestamp")
   )
   return(populate(args, interface))
 }
@@ -426,4 +426,4 @@ test_that("unmarshal error", {
   expect_equal(err$code, "Foo")
   expect_equal(err$status_code, 404)
   expect_equal(err$error_response$RequestID, "Baz")
-})
\ No newline at end of file
+})
